Coverage report

# Coverage report: 71.82%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 522 | 126 | 0 | 202 | 36 | 71.82%
/Users/marco/Code/django-rosetta/rosetta/__init__ | 3 | 0 | 0 | 0 | 0 | 100.00%
/Users/marco/Code/django-rosetta/rosetta/conf/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/Users/marco/Code/django-rosetta/rosetta/conf/settings | 12 | 0 | 0 | 0 | 0 | 100.00%
/Users/marco/Code/django-rosetta/rosetta/models | 1 | 0 | 0 | 0 | 0 | 100.00%
/Users/marco/Code/django-rosetta/rosetta/poutil | 110 | 49 | 0 | 72 | 9 | 50.55%
/Users/marco/Code/django-rosetta/rosetta/signals | 3 | 0 | 0 | 0 | 0 | 100.00%
/Users/marco/Code/django-rosetta/rosetta/storage | 67 | 17 | 0 | 10 | 3 | 71.43%
/Users/marco/Code/django-rosetta/rosetta/templatetags/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/Users/marco/Code/django-rosetta/rosetta/templatetags/rosetta | 59 | 11 | 0 | 6 | 1 | 81.54%
/Users/marco/Code/django-rosetta/rosetta/urls | 5 | 0 | 0 | 0 | 0 | 100.00%
/Users/marco/Code/django-rosetta/rosetta/views | 262 | 49 | 0 | 114 | 23 | 78.72%